
[![](https://codecov.io/gh/nickderobertis/py-file-conf/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/py-file-conf)

# py-file-conf

## Overview

Generate Python configuration files from functions and classes and run them from the command line or Python

## Getting Started

Install `pyfileconf`:

```
pip install pyfileconf
```

A simple example:

```python
import pyfileconf

# Do something with pyfileconf
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/py-file-conf/
)

## Author

Created by Nick DeRobertis. MIT License.